Class: Google::Apis::FirebasehostingV1::CustomDomainMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirebasehostingV1::CustomDomainMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasehosting_v1/classes.rb,
lib/google/apis/firebasehosting_v1/representations.rb,
lib/google/apis/firebasehosting_v1/representations.rb
Overview
Metadata associated with aCustomDomain operation.
Instance Attribute Summary collapse
-
#cert_state ⇒ String
The
CertStateof the domain name's SSL certificate. -
#host_state ⇒ String
The
HostStateof the domain name thisCustomDomainrefers to. -
#issues ⇒ Array<Google::Apis::FirebasehostingV1::Status>
A list of issues that are currently preventing Hosting from completing the operation.
-
#live_migration_steps ⇒ Array<Google::Apis::FirebasehostingV1::LiveMigrationStep>
A set of DNS record updates and ACME challenges that allow you to transition domain names to Firebase Hosting with zero downtime.
-
#ownership_state ⇒ String
The
OwnershipStateof the domain name thisCustomDomainrefers to. -
#quick_setup_updates ⇒ Google::Apis::FirebasehostingV1::DnsUpdates
A set of DNS record updates that you should make to allow Hosting to serve secure content in response to requests against your domain name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomDomainMetadata
constructor
A new instance of CustomDomainMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomDomainMetadata
Returns a new instance of CustomDomainMetadata.
118 119 120 |
# File 'lib/google/apis/firebasehosting_v1/classes.rb', line 118 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cert_state ⇒ String
The CertState of the domain name's SSL certificate.
Corresponds to the JSON property certState
78 79 80 |
# File 'lib/google/apis/firebasehosting_v1/classes.rb', line 78 def cert_state @cert_state end |
#host_state ⇒ String
The HostState of the domain name this CustomDomain refers to.
Corresponds to the JSON property hostState
83 84 85 |
# File 'lib/google/apis/firebasehosting_v1/classes.rb', line 83 def host_state @host_state end |
#issues ⇒ Array<Google::Apis::FirebasehostingV1::Status>
A list of issues that are currently preventing Hosting from completing the
operation. These are generally DNS-related issues that Hosting encounters when
querying a domain name's records or attempting to mint an SSL certificate.
Corresponds to the JSON property issues
90 91 92 |
# File 'lib/google/apis/firebasehosting_v1/classes.rb', line 90 def issues @issues end |
#live_migration_steps ⇒ Array<Google::Apis::FirebasehostingV1::LiveMigrationStep>
A set of DNS record updates and ACME challenges that allow you to transition
domain names to Firebase Hosting with zero downtime. These updates allow
Hosting to create an SSL certificate and establish ownership for your custom
domain before Hosting begins serving traffic on it. If your domain name is
already in active use with another provider, add one of the challenges and
make the recommended DNS updates. After adding challenges and adjusting DNS
records as necessary, wait for the ownershipState to be OWNERSHIP_ACTIVE
and the certState to be CERT_ACTIVE before sending traffic to Hosting.
Corresponds to the JSON property liveMigrationSteps
102 103 104 |
# File 'lib/google/apis/firebasehosting_v1/classes.rb', line 102 def live_migration_steps @live_migration_steps end |
#ownership_state ⇒ String
The OwnershipState of the domain name this CustomDomain refers to.
Corresponds to the JSON property ownershipState
107 108 109 |
# File 'lib/google/apis/firebasehosting_v1/classes.rb', line 107 def ownership_state @ownership_state end |
#quick_setup_updates ⇒ Google::Apis::FirebasehostingV1::DnsUpdates
A set of DNS record updates that you should make to allow Hosting to serve
secure content in response to requests against your domain name. These updates
present the current state of your domain name's DNS records when Hosting last
queried them, and the desired set of records that Hosting needs to see before
your custom domain can be fully active.
Corresponds to the JSON property quickSetupUpdates
116 117 118 |
# File 'lib/google/apis/firebasehosting_v1/classes.rb', line 116 def quick_setup_updates @quick_setup_updates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
123 124 125 126 127 128 129 130 |
# File 'lib/google/apis/firebasehosting_v1/classes.rb', line 123 def update!(**args) @cert_state = args[:cert_state] if args.key?(:cert_state) @host_state = args[:host_state] if args.key?(:host_state) @issues = args[:issues] if args.key?(:issues) @live_migration_steps = args[:live_migration_steps] if args.key?(:live_migration_steps) @ownership_state = args[:ownership_state] if args.key?(:ownership_state) @quick_setup_updates = args[:quick_setup_updates] if args.key?(:quick_setup_updates) end |